@@ -67,7 +67,7 @@ docnames.NULL <- function(x) {
 #' (sparse) \link[Matrix]{Matrix}, \link[tm]{TermDocumentMatrix},
 #' \link[tm]{DocumentTermMatrix}, \link{data.frame}, and other \link{dfm}
 #' objects.
-#' @param x a candidate object for checking or coercion to \link{dfm} 
+#' @param x a candidate object for checking or coercion to \link{dfm}
 #' @return \code{as.dfm} converts an input object into a \link{dfm}.  Row names
 #'   are used for docnames, and column names for featnames, of the resulting
 #'   dfm.
@@ -94,21 +94,21 @@ as.dfm.dfm <- function(x) {
 #' @method as.dfm matrix
 #' @export
 as.dfm.matrix <- function(x) {
-    as_dfm_constructor(x)
+    matrix2dfm(x)
 }
 
 #' @noRd
 #' @method as.dfm Matrix
 #' @export
 as.dfm.Matrix <- function(x) {
-    as_dfm_constructor(x)
+    matrix2dfm(x)
 }
 
 #' @noRd
 #' @method as.dfm data.frame
 #' @export
 as.dfm.data.frame <- function(x) {
-    as_dfm_constructor(as.matrix(x, rownames.force = TRUE))
+    matrix2dfm(as.matrix(x, rownames.force = TRUE))
 }
 
 #' @noRd
@@ -124,8 +124,8 @@ as.dfm.dfmSparse <- function(x) {
 as.dfm.DocumentTermMatrix <- function(x){
     as.dfm(
         sparseMatrix(i = x$i, j = x$j, x = x$v, 
-                     dimnames = list(rownames(x), colnames(x)))
-    )
+                     dimnames = list(docs = rownames(x), 
+                                     features = colnames(x))))
 }
 
 #' @noRd
@@ -134,18 +134,51 @@ as.dfm.DocumentTermMatrix <- function(x){
 as.dfm.TermDocumentMatrix <- function(x){
     as.dfm(
         sparseMatrix(i = x$j, j = x$i, x = x$v, 
-                     dimnames = list(colnames(x), rownames(x)))
-    )
+                     dimnames = list(colnames(x), rownames(x))))
 }
 
-as_dfm_constructor <- function(x) {
-    x <- Matrix(x, sparse = TRUE) # dimnames argument is not working
-    names(dimnames(x)) <- c("docs", "features")
-    if (nrow(x) > 0 && is.null(rownames(x))) 
-        rownames(x) <- paste0(quanteda_options("base_docname"), seq_len(nrow(x)))
-    if (ncol(x) > 0 && is.null(colnames(x)))
-        colnames(x) <- paste0(quanteda_options("base_featname"), seq_len(ncol(x)))
-    new("dfm", x, docvars = data.frame(row.names = rownames(x)))
+#' Conversts a Matrix to a dfm
+#' @param x a Matrix
+#' @param slots slots a list of values to be assigned to slots
+#' @keywords internal
+matrix2dfm <- function(x, slots = NULL) {
+   
+    rowname <- rownames(x)
+    if (nrow(x) > length(rowname))
+        rowname <- paste0(quanteda_options("base_docname"), seq_len(nrow(x)))
+    
+    colname <- colnames(x)
+    if (ncol(x) > length(colname))
+        colname <- paste0(quanteda_options("base_featname"), seq_len(ncol(x)))
+    
+    x <- Matrix(x, sparse = TRUE)
+    dimnames(x) <- list(docs = rowname, features = colname)
+    
+    # Force dfm to have docvars
+    if (is.character(rownames(x))) {
+        x <- new("dfm", as(x, 'dgCMatrix'), docvars = data.frame(row.names = make.unique(rownames(x))))
+    } else {
+        x <- new("dfm", as(x, 'dgCMatrix'))
+    }
+    
+    set_dfm_slots(x, slots)
+}
+
+#' Set values to a dfm's S4 slots
+#' @param x a dfm 
+#' @param slots a list of values extracted using \code{attributes} and to be assigned to slots 
+#' @param exceptions names of slots to be ignored
+#' @keywords internal
+set_dfm_slots <- function(x, slots = NULL, exceptions = NULL) {
+    if (is.null(slots)) return(x)
+    sname <- slotNames("dfm")
+    sname <- setdiff(sname, c("Dim", "Dimnames", "i", "p", "x", "factors", exceptions))
+    for (s in sname) {
+        try({
+            slot(x, s) <- slots[[s]]
+        }, silent = TRUE)
+    }
+    return(x)
 }
 
 #' @rdname as.dfm
@@ -262,7 +295,7 @@ topfeatures.dfm <- function(x, n = 10, decreasing = TRUE,
 #' @examples 
 #' inaug_dfm <- dfm(data_corpus_inaugural, verbose = FALSE)
 #' sparsity(inaug_dfm)
-#' sparsity(dfm_trim(inaug_dfm, min_count = 5))
+#' sparsity(dfm_trim(inaug_dfm, min_termfreq = 5))
 #' @export
 sparsity <- function(x) {
     UseMethod("sparsity")
