@@ -111,7 +111,7 @@ tokens_lookup.tokens <- function(x, dictionary, levels = 1:5,
     index <- index_types(types, valuetype, case_insensitive) # index types before the loop
     for (h in seq_along(dictionary)) {
         values <- split_dictionary_values(dictionary[[h]], attr(x, 'concatenator'))
-        values_temp <- regex2id(values, index = index)
+        values_temp <- pattern2id(values, index = index)
         values_id <- c(values_id, values_temp)
         keys_id <- c(keys_id, rep(h, length(values_temp)))
     }
